==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skgbasegui/skgwidgetcollectiondesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A collection of widgets for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgwidgetcollectiondesignerplugin.h"
#include "skgcomboboxdesignerplugin.h"
#include "skgtableviewdesignerplugin.h"
#include "skgtreeviewdesignerplugin.h"
#include "skgdateeditdesignerplugin.h"
#include "skgcalculatoreditdesignerplugin.h"
#include "skggraphicsviewdesignerplugin.h"
#include "skgtablewithgraphdesignerplugin.h"

#include <QtPlugin>

SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        widgets.append(new SKGCalculatorEditDesignerPlugin(this));
        widgets.append(new SKGComboBoxDesignerPlugin(this));
        widgets.append(new SKGDateEditDesignerPlugin(this));
        widgets.append(new SKGGraphicsViewDesignerPlugin(this));
        widgets.append(new SKGTableViewDesignerPlugin(this));
        widgets.append(new SKGTreeViewDesignerPlugin(this));
        widgets.append(new SKGTableWithGraphDesignerPlugin(this));
}

QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::customWidgets() const
{
        return widgets;
}

Q_EXPORT_PLUGIN2(sroogeui, SKGWidgetCollectionDesignerPlugin)

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbasegui/skgwidgetcollectiondesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A collection of widgets for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgwidgetcollectiondesignerplugin.h"
#include "skgcomboboxdesignerplugin.h"
#include "skgtableviewdesignerplugin.h"
#include "skgtreeviewdesignerplugin.h"
#include "skgdateeditdesignerplugin.h"
#include "skgcalculatoreditdesignerplugin.h"
#include "skggraphicsviewdesignerplugin.h"
#include "skgtablewithgraphdesignerplugin.h"

#include <QtPlugin>

SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        widgets.append(new SKGCalculatorEditDesignerPlugin(this));
        widgets.append(new SKGComboBoxDesignerPlugin(this));
        widgets.append(new SKGDateEditDesignerPlugin(this));
        widgets.append(new SKGGraphicsViewDesignerPlugin(this));
        widgets.append(new SKGTableViewDesignerPlugin(this));
        widgets.append(new SKGTreeViewDesignerPlugin(this));
        widgets.append(new SKGTableWithGraphDesignerPlugin(this));
}

QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::customWidgets() const
{
        return widgets;
}

Q_EXPORT_PLUGIN2(skroogeui, SKGWidgetCollectionDesignerPlugin)
